coherence.upnp.devices.media_server_client (module) — Cohen3 0.8.0 documentation

# coherence.upnp.devices.media_server_client (module)

## `MediaServerClient`

A class representing an media server client device.

class `MediaServerClient`(device)

  Bases: `eventdispatcher.eventdispatcher.EventDispatcher`, `coherence.log.LogAble`

  Changed in version 0.9.0:

  - Introduced inheritance from EventDispatcher

  - The emitted events changed:

    > - Coherence.UPnP.DeviceClient.detection_completed => device_client_detection_completed

  - Changed some class variable to benefit from the EventDispatcher’s properties:

    > - `detection_completed`
    > - `content_directory`

  `logCategory` = 'ms_client'
  `detection_completed`

    To know whenever the device detection has completed. Defaults to False and it will be set automatically to True by the class method `service_notified()`.

  `content_directory`
  `remove`()
  `service_notified`(service)
  `state_variable_change`(variable, usn)
  `print_results`(results)
  `process_meta`(results)